import rtest

datadir = "../samples"

vcf = datadir+"/sample.vcf"

def test01(n):
    """vcf2tsv converts a CSV to a tabulated test file, e.g.

       vcf2tsv samples/sample.vcf

    outputs

```
#CHROM  POS     ID      REF     ALT     QUAL    FILTER  AA      AC      AF      AN      DB      DP      H2NS
19      111     .       A       C       9.6     .       .       .       .       .       .       .       . .
19      112     .       A       G       10      .       .       .       .       .       .       .       . .
20      14370   rs6054257       G       A       29      PASS    .       .       0.5     .       .       14.3
```

    >>> rtest.run_stdout(f"vcf2tsv {vcf}", ext="tsv")

    """
    pass


if __name__ == "__main__":
    import doctest
    rtest.setup()
    doctest.testmod()



#!/usr/bin/env python3
# Transform VCF to BED file
#
import sys

for line in sys.stdin:
    if line.startswith('#'):
        continue
    fields = line.strip().split()
    # VCF is 1-based, BED is 0-based half open
    # print out chrom, start, end, 
    chrom = fields[0]
    start = int(fields[1]) - 1
    span = len(fields[3]) # handle multi-base alleles
    end = start + span
    name = fields[2]
    print("\t".join(str(x) for x in [chrom, start, end, name]))



import argparse, csv, os, sys

parser=argparse.ArgumentParser(description="Determines the index of individuals\
 of a given ethnicity within a 1000 Genomes VCF")
parser.add_argument("VCF", type=str, help="VCF of 1000 Genomes individuals")
parser.add_argument("Population", type=str, help="1KG identifier for population\
to be found in the index, enter \"ALL|\" to print index for all populations in \
the VCF")
arg=parser.parse_args()

a=os.path.abspath(sys.argv[0]).split("/")[:-1]
b="/".join(a)

try:
	 open(b+"/1KG_IDs.txt")
except IOError:
	print "Missing file \"1KG_IDs.txt\" containing the IDs for 1000 Genomes"

popdict={}
with open(b+"/1KG_IDs.txt") as t:
	for line in csv.reader(t,delimiter='\t'):
		popdict[line[1]]=line[0]

with open(arg.VCF) as t:
	for line in csv.reader(t,delimiter='\t'):
		if line[0]=='#CHROM':
			for j in range(len(line)):
				if 'NA' in line[j] or 'HG' in line[j]:
					vcfind=line[j:]
					break

indict={}
for i in range(len(vcfind)):
	try:
		eth=popdict[vcfind[i]]
	except:
		print"Non 1000 Genomes individuals found in VCF"
	if eth in indict.keys():
		indict[eth].append(i)
	else:
		indict[eth]=[i]

if arg.Population=="All":
	for j in indict.keys():
		l=[str(i) for i in indict[j]]
		print j,"=",",".join(l)

else:
	try:
		indict[arg.Population]
	except IOError:
		print "Population not in VCF or invalid population ID"
	l=[str(i) for i in indict[arg.Population]]
	print ",".join(l)



import os
import sys
import pprint
import difflib
import inspect
import re
from subprocess import Popen, PIPE

bindir = "../build"

regressiondir = "data/regression"
tmpdir = "tmp"

VERSION = open("../VERSION").read().strip()

def cat(cmd):
    head(cmd, -1)

def head(cmd, lines=4):
    cmd2 = cmd.split(" ")
    # print("-------------------->",cmd2,file=sys.stderr)
    cmd1 = cmd2[0]
    if not os.path.isfile(cmd1):
        cmd1 = f"{bindir}/{cmd1}"
    cmds = [cmd1]+cmd2[1:]
    p = Popen(cmds, stdout=PIPE, stderr=PIPE, close_fds=True)
    output = p.communicate()
    out = output[0]
    if len(out) == 0:
        # if stdout is empty fetch stderr
        out = output[1]
    # out=subprocess.check_output(cmd2, universal_newlines=True)
    header = out.decode().expandtabs(tabsize=8).split("\n")[0:lines]
    header = ['>' if l=='' else l for l in header]
    header = [l.replace(VERSION+" ", "") for l in header]
    header = [l.replace("../build/", "") for l in header]
    print("\n".join(header))

def run_stdout(cmd, ext = "vcf"):
    os.makedirs(tmpdir,exist_ok=True)
    curframe = inspect.currentframe()
    # pp = pprint.PrettyPrinter(indent=4)
    # pp.pprint(inspect.getouterframes(curframe))
    # print("------------n")
    calframe = inspect.getouterframes(curframe, 1)
    p = re.compile('\[([0-9])\]')
    index = p.findall(calframe[1].filename)[0]

    name = calframe[1].filename[0:-4]
    if "doctest" in name:
        name = name[9:-3]
    else:
        name = name[18:-1]

    name += "_"+index
    if ext:
        name += "." + ext

    tmpfn = tmpdir + "/" + name
    os.system(f"{bindir}/{cmd} > {tmpfn}")
    cmpfn = regressiondir+"/"+name
    sys.stdout.writelines(difflib.unified_diff(open(cmpfn).readlines(),open(tmpfn).readlines(),cmpfn,tmpfn,n=1))
    print(f"output in <a href=\"../data/regression/{name}\">{name}</a>")
